==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/LineType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LineType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LineType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="startStyle" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="endStyle" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="showCaption" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="captionHorizontalOffset" type="{http://www.w3.org/2001/XMLSchema}float" default="0" /&gt;
 *       &lt;attribute name="captionVerticalOffset" type="{http://www.w3.org/2001/XMLSchema}float" default="0" /&gt;
 *       &lt;attribute name="captionPositioning" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="leaderLineLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" /&gt;
 *       &lt;attribute name="leaderLineOffsetLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" /&gt;
 *       &lt;attribute name="leaderLineExtensionLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LineType")
public class LineType {

    @XmlAttribute(name = "startStyle")
    protected String startStyle;
    @XmlAttribute(name = "endStyle")
    protected String endStyle;
    @XmlAttribute(name = "showCaption")
    protected Boolean showCaption;
    @XmlAttribute(name = "captionHorizontalOffset")
    protected Float captionHorizontalOffset;
    @XmlAttribute(name = "captionVerticalOffset")
    protected Float captionVerticalOffset;
    @XmlAttribute(name = "captionPositioning")
    protected String captionPositioning;
    @XmlAttribute(name = "leaderLineLength")
    protected Float leaderLineLength;
    @XmlAttribute(name = "leaderLineOffsetLength")
    protected Float leaderLineOffsetLength;
    @XmlAttribute(name = "leaderLineExtensionLength")
    protected Float leaderLineExtensionLength;

    /**
     * Gets the value of the startStyle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStartStyle() {
        if (startStyle == null) {
            return "";
        } else {
            return startStyle;
        }
    }

    /**
     * Sets the value of the startStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStartStyle(String value) {
        this.startStyle = value;
    }

    public boolean isSetStartStyle() {
        return (this.startStyle!= null);
    }

    /**
     * Gets the value of the endStyle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndStyle() {
        if (endStyle == null) {
            return "";
        } else {
            return endStyle;
        }
    }

    /**
     * Sets the value of the endStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndStyle(String value) {
        this.endStyle = value;
    }

    public boolean isSetEndStyle() {
        return (this.endStyle!= null);
    }

    /**
     * Gets the value of the showCaption property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCaption() {
        if (showCaption == null) {
            return false;
        } else {
            return showCaption;
        }
    }

    /**
     * Sets the value of the showCaption property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCaption(boolean value) {
        this.showCaption = value;
    }

    public boolean isSetShowCaption() {
        return (this.showCaption!= null);
    }

    public void unsetShowCaption() {
        this.showCaption = null;
    }

    /**
     * Gets the value of the captionHorizontalOffset property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getCaptionHorizontalOffset() {
        if (captionHorizontalOffset == null) {
            return  0.0F;
        } else {
            return captionHorizontalOffset;
        }
    }

    /**
     * Sets the value of the captionHorizontalOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCaptionHorizontalOffset(float value) {
        this.captionHorizontalOffset = value;
    }

    public boolean isSetCaptionHorizontalOffset() {
        return (this.captionHorizontalOffset!= null);
    }

    public void unsetCaptionHorizontalOffset() {
        this.captionHorizontalOffset = null;
    }

    /**
     * Gets the value of the captionVerticalOffset property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getCaptionVerticalOffset() {
        if (captionVerticalOffset == null) {
            return  0.0F;
        } else {
            return captionVerticalOffset;
        }
    }

    /**
     * Sets the value of the captionVerticalOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCaptionVerticalOffset(float value) {
        this.captionVerticalOffset = value;
    }

    public boolean isSetCaptionVerticalOffset() {
        return (this.captionVerticalOffset!= null);
    }

    public void unsetCaptionVerticalOffset() {
        this.captionVerticalOffset = null;
    }

    /**
     * Gets the value of the captionPositioning property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCaptionPositioning() {
        if (captionPositioning == null) {
            return "";
        } else {
            return captionPositioning;
        }
    }

    /**
     * Sets the value of the captionPositioning property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCaptionPositioning(String value) {
        this.captionPositioning = value;
    }

    public boolean isSetCaptionPositioning() {
        return (this.captionPositioning!= null);
    }

    /**
     * Gets the value of the leaderLineLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineLength() {
        if (leaderLineLength == null) {
            return  0.0F;
        } else {
            return leaderLineLength;
        }
    }

    /**
     * Sets the value of the leaderLineLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineLength(float value) {
        this.leaderLineLength = value;
    }

    public boolean isSetLeaderLineLength() {
        return (this.leaderLineLength!= null);
    }

    public void unsetLeaderLineLength() {
        this.leaderLineLength = null;
    }

    /**
     * Gets the value of the leaderLineOffsetLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineOffsetLength() {
        if (leaderLineOffsetLength == null) {
            return  0.0F;
        } else {
            return leaderLineOffsetLength;
        }
    }

    /**
     * Sets the value of the leaderLineOffsetLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineOffsetLength(float value) {
        this.leaderLineOffsetLength = value;
    }

    public boolean isSetLeaderLineOffsetLength() {
        return (this.leaderLineOffsetLength!= null);
    }

    public void unsetLeaderLineOffsetLength() {
        this.leaderLineOffsetLength = null;
    }

    /**
     * Gets the value of the leaderLineExtensionLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineExtensionLength() {
        if (leaderLineExtensionLength == null) {
            return  0.0F;
        } else {
            return leaderLineExtensionLength;
        }
    }

    /**
     * Sets the value of the leaderLineExtensionLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineExtensionLength(float value) {
        this.leaderLineExtensionLength = value;
    }

    public boolean isSetLeaderLineExtensionLength() {
        return (this.leaderLineExtensionLength!= null);
    }

    public void unsetLeaderLineExtensionLength() {
        this.leaderLineExtensionLength = null;
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/LineType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines a set of attributes for Line annotations.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for LineType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="LineType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="startStyle" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="endStyle" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="showCaption" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="captionHorizontalOffset" type="{http://www.w3.org/2001/XMLSchema}float" default="0" />
 *       <attribute name="captionVerticalOffset" type="{http://www.w3.org/2001/XMLSchema}float" default="0" />
 *       <attribute name="captionPositioning" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="leaderLineLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" />
 *       <attribute name="leaderLineOffsetLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" />
 *       <attribute name="leaderLineExtensionLength" type="{http://www.w3.org/2001/XMLSchema}float" default="0" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LineType")
public class LineType {

    @XmlAttribute(name = "startStyle")
    protected String startStyle;
    @XmlAttribute(name = "endStyle")
    protected String endStyle;
    @XmlAttribute(name = "showCaption")
    protected Boolean showCaption;
    @XmlAttribute(name = "captionHorizontalOffset")
    protected Float captionHorizontalOffset;
    @XmlAttribute(name = "captionVerticalOffset")
    protected Float captionVerticalOffset;
    @XmlAttribute(name = "captionPositioning")
    protected String captionPositioning;
    @XmlAttribute(name = "leaderLineLength")
    protected Float leaderLineLength;
    @XmlAttribute(name = "leaderLineOffsetLength")
    protected Float leaderLineOffsetLength;
    @XmlAttribute(name = "leaderLineExtensionLength")
    protected Float leaderLineExtensionLength;

    /**
     * Gets the value of the startStyle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStartStyle() {
        if (startStyle == null) {
            return "";
        } else {
            return startStyle;
        }
    }

    /**
     * Sets the value of the startStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStartStyle(String value) {
        this.startStyle = value;
    }

    public boolean isSetStartStyle() {
        return (this.startStyle!= null);
    }

    /**
     * Gets the value of the endStyle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndStyle() {
        if (endStyle == null) {
            return "";
        } else {
            return endStyle;
        }
    }

    /**
     * Sets the value of the endStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndStyle(String value) {
        this.endStyle = value;
    }

    public boolean isSetEndStyle() {
        return (this.endStyle!= null);
    }

    /**
     * Gets the value of the showCaption property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCaption() {
        if (showCaption == null) {
            return false;
        } else {
            return showCaption;
        }
    }

    /**
     * Sets the value of the showCaption property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCaption(boolean value) {
        this.showCaption = value;
    }

    public boolean isSetShowCaption() {
        return (this.showCaption!= null);
    }

    public void unsetShowCaption() {
        this.showCaption = null;
    }

    /**
     * Gets the value of the captionHorizontalOffset property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getCaptionHorizontalOffset() {
        if (captionHorizontalOffset == null) {
            return  0.0F;
        } else {
            return captionHorizontalOffset;
        }
    }

    /**
     * Sets the value of the captionHorizontalOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCaptionHorizontalOffset(float value) {
        this.captionHorizontalOffset = value;
    }

    public boolean isSetCaptionHorizontalOffset() {
        return (this.captionHorizontalOffset!= null);
    }

    public void unsetCaptionHorizontalOffset() {
        this.captionHorizontalOffset = null;
    }

    /**
     * Gets the value of the captionVerticalOffset property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getCaptionVerticalOffset() {
        if (captionVerticalOffset == null) {
            return  0.0F;
        } else {
            return captionVerticalOffset;
        }
    }

    /**
     * Sets the value of the captionVerticalOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCaptionVerticalOffset(float value) {
        this.captionVerticalOffset = value;
    }

    public boolean isSetCaptionVerticalOffset() {
        return (this.captionVerticalOffset!= null);
    }

    public void unsetCaptionVerticalOffset() {
        this.captionVerticalOffset = null;
    }

    /**
     * Gets the value of the captionPositioning property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCaptionPositioning() {
        if (captionPositioning == null) {
            return "";
        } else {
            return captionPositioning;
        }
    }

    /**
     * Sets the value of the captionPositioning property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCaptionPositioning(String value) {
        this.captionPositioning = value;
    }

    public boolean isSetCaptionPositioning() {
        return (this.captionPositioning!= null);
    }

    /**
     * Gets the value of the leaderLineLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineLength() {
        if (leaderLineLength == null) {
            return  0.0F;
        } else {
            return leaderLineLength;
        }
    }

    /**
     * Sets the value of the leaderLineLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineLength(float value) {
        this.leaderLineLength = value;
    }

    public boolean isSetLeaderLineLength() {
        return (this.leaderLineLength!= null);
    }

    public void unsetLeaderLineLength() {
        this.leaderLineLength = null;
    }

    /**
     * Gets the value of the leaderLineOffsetLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineOffsetLength() {
        if (leaderLineOffsetLength == null) {
            return  0.0F;
        } else {
            return leaderLineOffsetLength;
        }
    }

    /**
     * Sets the value of the leaderLineOffsetLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineOffsetLength(float value) {
        this.leaderLineOffsetLength = value;
    }

    public boolean isSetLeaderLineOffsetLength() {
        return (this.leaderLineOffsetLength!= null);
    }

    public void unsetLeaderLineOffsetLength() {
        this.leaderLineOffsetLength = null;
    }

    /**
     * Gets the value of the leaderLineExtensionLength property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeaderLineExtensionLength() {
        if (leaderLineExtensionLength == null) {
            return  0.0F;
        } else {
            return leaderLineExtensionLength;
        }
    }

    /**
     * Sets the value of the leaderLineExtensionLength property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeaderLineExtensionLength(float value) {
        this.leaderLineExtensionLength = value;
    }

    public boolean isSetLeaderLineExtensionLength() {
        return (this.leaderLineExtensionLength!= null);
    }

    public void unsetLeaderLineExtensionLength() {
        this.leaderLineExtensionLength = null;
    }

}
